@@ -32,6 +32,11 @@
 
 #include <glib/gi18n.h>
 
+#include <libpanel-util/panel-error.h>
+#include <libpanel-util/panel-launch.h>
+#include <libpanel-util/panel-session-manager.h>
+#include <libpanel-util/panel-show.h>
+
 #include "applet.h"
 #include "panel-config-global.h"
 #include "panel-gconf.h"
@@ -44,12 +49,10 @@
 #include "panel-run-dialog.h"
 #include "panel-a11y.h"
 #include "panel-lockdown.h"
-#include "panel-logout.h"
 #include "panel-compatibility.h"
-#include "panel-gdm.h"
 #include "panel-icon-names.h"
 
-G_DEFINE_TYPE (PanelActionButton, panel_action_button, BUTTON_TYPE_WIDGET);
+G_DEFINE_TYPE (PanelActionButton, panel_action_button, BUTTON_TYPE_WIDGET)
 
 #define PANEL_ACTION_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_ACTION_BUTTON, PanelActionButtonPrivate))
 
@@ -155,7 +158,8 @@ panel_action_lock_invoke_menu (PanelActionButton *button,
 static void
 panel_action_logout (GtkWidget *widget)
 {
-	gboolean not_prompt;
+	PanelSessionManager *manager;
+	gboolean             not_prompt;
 
 	not_prompt = gconf_client_get_bool (panel_gconf_get_client (),
 					    LOGOUT_PROMPT_KEY, NULL);
@@ -163,28 +167,39 @@ panel_action_logout (GtkWidget *widget)
 	 * safer */
 	not_prompt = !not_prompt;
 
+	manager = panel_session_manager_get ();
+
 	if (not_prompt)
-		panel_session_request_logout ();
+		panel_session_manager_request_logout (manager,
+						      PANEL_SESSION_MANAGER_LOGOUT_MODE_NO_CONFIRMATION);
 	else
-		panel_logout_new (PANEL_LOGOUT_DIALOG_LOGOUT,
-				  gtk_widget_get_screen (widget),
-				  gtk_get_current_event_time ());
+		/* FIXME: we need to use widget to get the screen for the
+		 * confirmation dialog, see
+		 * http://bugzilla.gnome.org/show_bug.cgi?id=536914 */
+		panel_session_manager_request_logout (manager,
+						      PANEL_SESSION_MANAGER_LOGOUT_MODE_NORMAL);
 }
 
 static void
 panel_action_shutdown (GtkWidget *widget)
 {
-	panel_logout_new (PANEL_LOGOUT_DIALOG_SHUTDOWN,
-			  gtk_widget_get_screen (widget),
-			  gtk_get_current_event_time ());
+	PanelSessionManager *manager;
+
+	manager = panel_session_manager_get ();
+	panel_session_manager_request_shutdown (manager);
 }
 
 static gboolean
 panel_action_shutdown_reboot_is_disabled (void)
 {
-	return (panel_lockdown_get_disable_log_out() ||
-	(!gdm_supports_logout_action (GDM_LOGOUT_ACTION_SHUTDOWN) &&
-	 !gdm_supports_logout_action (GDM_LOGOUT_ACTION_REBOOT)));
+	PanelSessionManager *manager;
+
+	if (panel_lockdown_get_disable_log_out())
+		return TRUE;
+
+	manager = panel_session_manager_get ();
+
+	return (!panel_session_manager_is_shutdown_available (manager));
 }
 
 /* Run Application
@@ -202,23 +217,11 @@ static void
 panel_action_search (GtkWidget *widget)
 {
 	GdkScreen *screen;
-	GError    *error = NULL;
 
 	screen = gtk_widget_get_screen (widget);
-	panel_launch_desktop_file ("gnome-search-tool.desktop",
-				   "gnome-search-tool",
-				   screen,
-				   &error);
-	if (error) {
-		char *primary;
-		primary = g_strdup_printf (_("Could not execute '%s'"),
-					   "gnome-search-tool");
-		panel_error_dialog (NULL, screen,
-				    "cannot_exec_gnome-search-tool", TRUE,
-				    primary, error->message);
-		g_free (primary);
-		g_error_free (error);
-	}
+	panel_launch_desktop_file_with_fallback ("gnome-search-tool.desktop",
+						 "gnome-search-tool",
+						 screen, NULL);
 }
 
 /* Force Quit
@@ -226,7 +229,8 @@ panel_action_search (GtkWidget *widget)
 static void
 panel_action_force_quit (GtkWidget *widget)
 {
-	panel_force_quit (gtk_widget_get_screen (widget));
+	panel_force_quit (gtk_widget_get_screen (widget),
+			  gtk_get_current_event_time ());
 }
 
 /* Connect Server
@@ -244,13 +248,11 @@ panel_action_connect_server (GtkWidget *widget)
 					  &error);
 
 	if (error) {
-		GtkWidget *error_dialog;
-
-		error_dialog = panel_error_dialog (NULL, screen,
-						   "cannot_connect_server",
-						   TRUE,
-						   _("Could not connect to server"),
-						   error->message);
+		panel_error_dialog (NULL, screen,
+				    "cannot_connect_server",
+				    TRUE,
+				    _("Could not connect to server"),
+				    error->message);
 		g_clear_error (&error);
 	}
 }
@@ -294,7 +296,7 @@ static PanelAction actions [] = {
 		PANEL_ICON_LOGOUT,
 		/* when changing one of those two strings, don't forget to
 		 * update the ones in panel-menu-items.c (look for
-		 * panel:showusername|1) */
+		 * "1" (msgctxt: "panel:showusername")) */
 		N_("Log Out..."),
 		N_("Log out of this session to log in as a different user"),
 		"gospanel-20",
@@ -336,7 +338,7 @@ static PanelAction actions [] = {
 		PANEL_ICON_REMOTE, //FIXME icon
 		N_("Connect to Server..."),
 		N_("Connect to a remote computer or shared disk"),
-		"gospanel-563", //FIXME
+		"nautilus-server-connect",
 		"ACTION:connect-server:NEW",
 		panel_action_connect_server, NULL, NULL, NULL
 	},
@@ -519,7 +521,7 @@ panel_action_button_drag_data_get (GtkWidget          *widget,
 				     panel_find_applet_index (widget));
 
 	gtk_selection_data_set (
-		selection_data, selection_data->target,
+		selection_data, gtk_selection_data_get_target (selection_data),
 		8, (guchar *) drag_data, strlen (drag_data));
 
 	g_free (drag_data);
@@ -540,7 +542,7 @@ panel_action_button_clicked (GtkButton *gtk_button)
 	if (panel_global_config_get_drawer_auto_close ()) {
 		PanelToplevel *toplevel;
 
-		toplevel = PANEL_WIDGET (GTK_WIDGET (button)->parent)->toplevel;
+		toplevel = PANEL_WIDGET (gtk_widget_get_parent (GTK_WIDGET (button)))->toplevel;
 
 		if (panel_toplevel_get_is_attached (toplevel))
 			panel_toplevel_hide (toplevel, FALSE, -1);
@@ -616,8 +618,8 @@ panel_action_button_set_type (PanelActionButton     *button,
 	if (actions [type].icon_name != NULL)
 		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [type].icon_name);
 
-	gtk_tooltips_set_tip (panel_tooltips, GTK_WIDGET (button),
-			      _(actions [type].tooltip), NULL);
+	panel_util_set_tooltip_text (GTK_WIDGET (button),
+				     _(actions [type].tooltip));
 	panel_a11y_set_atk_name_desc (GTK_WIDGET (button), _(actions [type].tooltip), NULL);
 
 	panel_action_button_update_sensitivity (button);
@@ -814,8 +816,8 @@ panel_action_button_invoke_menu (PanelActionButton *button,
 
 		screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
-		panel_show_help (screen, "user-guide.xml",
-				 actions [button->priv->type].help_index);
+		panel_show_help (screen, "user-guide",
+				 actions [button->priv->type].help_index, NULL);
 
 		return;
 	}
@@ -887,14 +889,14 @@ panel_action_button_set_dnd_enabled (PanelActionButton *button,
 			{ "application/x-panel-applet-internal", 0, 0 }
 		};
 
-		GTK_WIDGET_UNSET_FLAGS (button, GTK_NO_WINDOW);
+		gtk_widget_set_has_window (GTK_WIDGET (button), TRUE);
 		gtk_drag_source_set (GTK_WIDGET (button), GDK_BUTTON1_MASK,
 				     dnd_targets, 1,
 				     GDK_ACTION_COPY | GDK_ACTION_MOVE);
 		if (actions [button->priv->type].icon_name != NULL)
 			gtk_drag_source_set_icon_name (GTK_WIDGET (button),
 						       actions [button->priv->type].icon_name);
-		GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
+		gtk_widget_set_has_window (GTK_WIDGET (button), FALSE);
 	} else
 		gtk_drag_source_unset (GTK_WIDGET (button));
 
